DeriveOrder

Struct DeriveOrder 

pub struct DeriveOrder {
Show 29 fields pub amount: Decimal, pub average_price: Decimal, pub cancel_reason: DeriveOrderCancelReason, pub creation_timestamp: i64, pub direction: DeriveOrderSide, pub filled_amount: Decimal, pub instrument_name: Ustr, pub is_transfer: bool, pub label: Ustr, pub last_update_timestamp: i64, pub limit_price: Decimal, pub max_fee: Decimal, pub mmp: bool, pub nonce: i64, pub order_fee: Decimal, pub order_id: String, pub order_status: DeriveOrderStatus, pub order_type: DeriveOrderType, pub quote_id: Option<String>, pub replaced_order_id: Option<String>, pub signature: String, pub signature_expiry_sec: i64, pub signer: Ustr, pub subaccount_id: i64, pub time_in_force: DeriveTimeInForce, pub trigger_price: Option<Decimal>, pub trigger_price_type: Option<DeriveTriggerPriceType>, pub trigger_reject_message: Option<String>, pub trigger_type: Option<DeriveTriggerType>,
}
Order record returned by private/order, private/get_orders, private/get_order_history, and the {subaccount_id}.orders WS channel.

Fields

amount: Decimal

Order amount in base units.

average_price: Decimal

Average fill price.

cancel_reason: DeriveOrderCancelReason

Cancel reason; DeriveOrderCancelReason::Empty when not cancelled.

creation_timestamp: i64

Creation timestamp (UNIX ms).

direction: DeriveOrderSide

Order side.

filled_amount: Decimal

Cumulative filled amount.

instrument_name: Ustr

Instrument identifier.

is_transfer: bool

Whether this order was generated via private/transfer_position.

label: Ustr

Free-form user label.

last_update_timestamp: i64

Last update timestamp (UNIX ms).

limit_price: Decimal

Limit price in quote currency.

max_fee: Decimal

Max fee in quote currency signed into the order.

mmp: bool

Whether MMP tags this order.

nonce: i64

Order nonce.

order_fee: Decimal

Total fees paid against this order.

order_id: String

Venue-assigned order ID (UUID-shaped).

order_status: DeriveOrderStatus

Order status.

order_type: DeriveOrderType

Order type.

quote_id: Option<String>

RFQ quote ID when the order is an RFQ execution.

replaced_order_id: Option<String>

Replaced order ID when this order resulted from a replace.

signature: String

65-byte order signature, 0x-prefixed hex.

signature_expiry_sec: i64

Signature expiry (UNIX seconds).

signer: Ustr

Session-key signer address.

subaccount_id: i64

Owning subaccount.

time_in_force: DeriveTimeInForce

Time-in-force.

trigger_price: Option<Decimal>

Trigger price for trigger orders.

trigger_price_type: Option<DeriveTriggerPriceType>

Trigger price source for trigger orders.

trigger_reject_message: Option<String>

Trigger rejection text when the trigger worker cannot submit.

trigger_type: Option<DeriveTriggerType>

Stop-loss or take-profit trigger flag.